package com.rnsocial;

import android.content.Context;
import android.content.pm.ApplicationInfo;
import android.content.pm.PackageManager;
import android.text.TextUtils;

import com.facebook.react.ReactPackage;
import com.facebook.react.bridge.JavaScriptModule;
import com.facebook.react.bridge.NativeModule;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.uimanager.ViewManager;
import com.rnsocial.login.ReactLoginModule;
import com.rnsocial.pay.ReactPayModule;
import com.rnsocial.share.ReactShareModule;
import com.umeng.commonsdk.UMConfigure;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * User : yh
 * Date : 17/5/4
 */

public class ReactSocialPackage implements ReactPackage {
    private static final String DEFAULT_UMENG_CHANNEL = "terminus";
    private static final String UMENG_APPKEY_MANIFEST = "UMENG_APPKEY";
    private static final String UMENG_CHANNEL_MANIFEST = "UMENG_CHANNEL";
    @Override
    public List<NativeModule> createNativeModules(ReactApplicationContext reactContext) {
        UMengInit(reactContext);
        List<NativeModule> modules = new ArrayList<>();
        modules.add(new ReactShareModule(reactContext));
        modules.add(new ReactPayModule(reactContext));
        modules.add(new ReactLoginModule(reactContext));
        modules.add(new ReactSocialModule(reactContext));
        return modules;
    }

    public List<Class<? extends JavaScriptModule>> createJSModules() {
        return Collections.emptyList();
    }

    @Override
    public List<ViewManager> createViewManagers(ReactApplicationContext reactContext) {
        return Collections.emptyList();
    }

    private void UMengInit(Context context){
        ApplicationInfo applicationInfo = null;
        try {
            applicationInfo = context.getApplicationContext().getPackageManager().getApplicationInfo(
                    context.getPackageName(),
                    PackageManager.GET_META_DATA);
        }catch (Throwable e) {
            e.printStackTrace();
        }
        if(applicationInfo == null || applicationInfo.metaData == null) {
            return;
        }
        String appkey = applicationInfo.metaData.getString(UMENG_APPKEY_MANIFEST, null);
        String channel = applicationInfo.metaData.getString(UMENG_CHANNEL_MANIFEST, DEFAULT_UMENG_CHANNEL);
        if(TextUtils.isEmpty(appkey)) {
            return;
        }
        UMConfigure.init(context,appkey,channel,UMConfigure.DEVICE_TYPE_PHONE,"");
    }
}
