package com.rnsocial;

import android.app.Activity;
import android.content.Intent;
import android.content.pm.PackageManager;

import com.rnsocial.login.LoginManager;
import com.rnsocial.login.channel.AlipayLogin;
import com.rnsocial.login.channel.QQLogin;
import com.rnsocial.login.channel.WechatLogin;
import com.rnsocial.login.enmus.LoginChannel;
import com.rnsocial.pay.PayManager;
import com.rnsocial.pay.channel.AliPay;
import com.rnsocial.pay.channel.QQWalletPay;
import com.rnsocial.pay.channel.UnionPay;
import com.rnsocial.pay.channel.WechatPay;
import com.rnsocial.pay.emums.PayChannel;
import com.rnsocial.share.ShareChannel;
import com.umeng.socialize.PlatformConfig;
import com.umeng.socialize.UMShareAPI;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;

/**
 * User : yh
 * Date : 17/5/4
 */

public class SocialConfig {
    private static List<ShareChannel> shareChannels = new ArrayList<>();
    private static String wechatId = "";
    private static String QQWalletId = "";
    private static  Activity content;


    public static void setShareAppConfig(String appKey,String appSecret,final ShareChannel... channels){
        if(channels == null){
            return;
        }
        for(ShareChannel channel : channels){
            if(shareChannels.indexOf(channel) < 0){
                shareChannels.add(channel);
            }
            if(channel == ShareChannel.Weixin || channel == ShareChannel.WeixinCycle){
                PlatformConfig.setWeixin(appKey,appSecret);
            }else if(channel == ShareChannel.Weibo){
                PlatformConfig.setSinaWeibo(appKey,appSecret,null);
            }else if(channel == ShareChannel.QQ || channel == ShareChannel.QZONE){
                PlatformConfig.setQQZone(appKey,appSecret);
            }else if(channel== ShareChannel.AliPayShare){
                PlatformConfig.setAlipay(appKey);
            } else if(channel == ShareChannel.DingTalk) {
                PlatformConfig.setDing(appKey);
            }
        }
        Collections.sort(shareChannels, new Comparator<ShareChannel>() {
            @Override
            public int compare(ShareChannel lhs, ShareChannel rhs) {
                if(lhs == null || rhs == null){
                    return 0;
                }
                return lhs.compareTo(rhs);
            }
        });
    }

    public static List<ShareChannel> getShareChannels(){
        return shareChannels;
    }

    public static void initAliPay(Activity activity){
        content = activity;
        LoginManager.getInstance().regist(LoginChannel.Alipay,new AlipayLogin(activity));
        PayManager.getInstance().regist(PayChannel.ALIPAY_APP,new AliPay(activity));
    }

    public static void initAliPayShare(Activity activity, String appId) {
        content = activity;

        setShareAppConfig(appId, "", ShareChannel.AliPayShare);
    }

    public static void initUnionPay(String mode){
        PayManager.getInstance().registUnion(PayChannel.UNIONPAY_APP, new UnionPay(),mode);
    }

    public static void initQQPay(Activity activity,String appId,String scheme){
        QQWalletId = appId;
        PayManager.getInstance().regist(PayChannel.QQPAY_APP,new QQWalletPay(activity, appId,scheme));
    }

    public static void initWechat(Activity mContext, String appId,String appSecret){
        content = mContext;

        PayManager.getInstance().regist(PayChannel.WECHATPAY_APP,new WechatPay(mContext,appId));
        LoginManager.getInstance().regist(LoginChannel.Wechat,new WechatLogin(mContext,appId,appSecret));
        wechatId = appId;
        setShareAppConfig(appId,appSecret,ShareChannel.Weixin,ShareChannel.WeixinCycle);
    }

    public static void initQQ(Activity activity,String appId,String appSecret){
        content = activity;

        LoginManager.getInstance().regist(LoginChannel.QQ,new QQLogin(activity,appId));
        setShareAppConfig(appId,appSecret,ShareChannel.QQ,ShareChannel.QZONE);

    }

    public static void initSina(Activity activity,String appId,String appSecret){
        content = activity;
        setShareAppConfig(appId,appSecret,ShareChannel.Weibo);
    }

    public static void initDingTalk(Activity activity, String appId, String appSecret) {
        content = activity;
        setShareAppConfig(appId,appSecret,ShareChannel.DingTalk);
    }

    public static void onActivityResult (Activity activity,int requestCode, int resultCode, Intent data){

        if(data!= null  &&  data.hasExtra("pay_result")){
            PayManager.getInstance().unionPayResultCallBack(requestCode,resultCode,data);
               return;
        }
        UMShareAPI.get(activity).onActivityResult(requestCode,resultCode,data);


    }


    public static boolean isInstall(String packageName) {
        try {
            content.getPackageManager().getPackageInfo(packageName, PackageManager.GET_META_DATA);
            return true;
        } catch (PackageManager.NameNotFoundException e) {
            e.printStackTrace();
        }
        return false;
    }

    public static String getWechatId(){
        return wechatId;
    }
    public static String getQQWalletId() {
        return QQWalletId;
    }
}
