package com.rnsocial.pay;

import android.content.Context;
import android.content.Intent;

import com.rnsocial.pay.channel.AliPay;
import com.rnsocial.pay.channel.UnionPay;
import com.rnsocial.pay.channel.WechatPay;
import com.rnsocial.pay.emums.PayChannel;
import com.rnsocial.pay.model.PayResult;

import java.util.HashMap;
import java.util.Map;


/**
 * User : yh
 * Date : 17/5/4
 */

public class PayManager {
    private static PayManager manager;
    private Map<PayChannel,PayService> payChannel ;
    private PayResultHandler payHandler;
    private Map<PayChannel,UnionPay> unionChannel ;
    private String unionMode  = "00";


    private PayManager(){
        payChannel = new HashMap<>();
        unionChannel = new HashMap<>();
    }

    public static PayManager getInstance(){
        if(manager == null){
            manager = new PayManager();
        }
        return manager;
    }
    public void registUnion(PayChannel channel,UnionPay payService,String mode){
        unionMode = mode;
        if(unionChannel.containsKey(channel)){
            return;
        }
        unionChannel.put(channel,payService);
    }

    public void regist(PayChannel channel,PayService service){
        if(payChannel.containsKey(channel)){
            return;
        }
        payChannel.put(channel,service);
    }

    public void Pay(PayChannel channel, Context mContext, HashMap<String, Object> payArgs, PayResultHandler handler){
        if(unionChannel.containsKey(channel)){
            payHandler = handler;
            UnionPay pay = unionChannel.get(channel);
            pay.pay(mContext,payArgs,handler,unionMode);

            return;
        }

        if(!payChannel.containsKey(channel)){
            handler.onResult(new PayResult(false,"pay.error","支付初始化失败"));
            return;
        }

        payHandler = handler;
        PayService pay = payChannel.get(channel);
        pay.pay(mContext,payArgs,handler);
    }


    public void unionPayResultCallBack(int requestCode, int resultCode, Intent data) {
        if(payHandler == null){
            return;
        }
        /*
        * 支付控件返回字符串:success、fail、cancel 分别代表支付成功，支付失败，支付取消
        */
        String str = data.getExtras().getString("pay_result");
        if (str.equalsIgnoreCase("success")) {
            payHandler.onResult(new PayResult(true,null,null));
        }else if(str.equalsIgnoreCase("cancel")){
            payHandler.onResult(new PayResult(false,"pay.cancel","支付取消"));
        }else{
            payHandler.onResult(new PayResult(false,"pay.error","支付失败"));
        }
        payHandler = null;
    }


    public void payResultCallBack(boolean success,String errorCode,String error){
        if(payHandler == null){
            return;
        }
        payHandler.onResult(new PayResult(success,errorCode,error));
        payHandler = null;
    }
}
