package com.rnsocial.pay.channel;

import android.app.Activity;
import android.content.Context;
import android.content.pm.PackageManager;
import android.os.Handler;
import android.os.Message;
import android.text.TextUtils;

import com.alipay.sdk.app.PayTask;
import com.rnsocial.pay.PayResultHandler;
import com.rnsocial.pay.PayService;
import com.rnsocial.pay.model.AliPayResult;
import com.rnsocial.pay.model.PayResult;

import java.util.Map;

/**
 * User : yh
 * Date : 17/5/4
 */

public class AliPay implements PayService{
    private static final int SDK_PAY_FLAG = 1;
    private static final int SDK_CHECK_FLAG = 2;
    private static final String ALIPAY_PACKAGE = "com.eg.android.AlipayGphone";
    private PayTask alipayTask;
    private PayResultHandler payHandler;

    public AliPay(){}

    public AliPay(Context mContext){
        init(mContext);
    }

    @Override
    public void init(Context mContext, Object... args) {
        if(mContext instanceof Activity){
            alipayTask = new PayTask((Activity) mContext);
        }
    }

    @Override
    public boolean checkSupport(Context mContext) {
        try {
            mContext.getPackageManager().getPackageInfo(ALIPAY_PACKAGE, PackageManager.GET_META_DATA);
            return true;
        } catch (PackageManager.NameNotFoundException e) {
            e.printStackTrace();
        }
        return false;
    }

    @Override
    public void pay(Context mContext, Map<String, Object> payArgs, PayResultHandler handler) {
        PayResult result ;
        if(alipayTask == null){
            result = new PayResult(false,"pay.init.error","支付初始化失败");
            handler.onResult(result);
            return;
        }
        if(!checkSupport(mContext)){
            result = new PayResult(false, "alipay.not.install", "未安装支付宝客户端");
            handler.onResult(result);
            return;
        }

        if(!payArgs.containsKey("sign") || TextUtils.isEmpty((String) payArgs.get("sign"))){
            result = new PayResult(false,"pay.error","参数解析失败");
            handler.onResult(result);
            return;
        }
        final String sign = (String)payArgs.get("sign");
        payHandler = handler;

        Runnable payRunnable = new Runnable() {
            @Override
            public void run() {
                // 构造PayTask 对象
//                PayTask alipay = new PayTask((Activity) context);
                // 调用支付接口，获取支付结果
                String result = alipayTask.pay(sign, true);
                Message msg = new Message();
                msg.what = SDK_PAY_FLAG;
                msg.obj = result;
                mHandler.sendMessage(msg);

            }
        };
        // 必须异步调用
        Thread payThread = new Thread(payRunnable);
        payThread.start();

    }

    private Handler mHandler = new Handler(){
        @Override
        public void handleMessage(Message msg) {
            PayResult result = new PayResult(false,"","");
            switch (msg.what){
                case SDK_PAY_FLAG:
                    AliPayResult pr = new AliPayResult((String) msg.obj);
                    String resultStatus = pr.getResultStatus();
                    // 判断resultStatus 为“9000”则代表支付成功，具体状态码代表含义可参考接口文档
                    if(TextUtils.equals(resultStatus,"9000")){
                        result = new PayResult(true,null,null);
                    }else{
                        // 判断resultStatus 为非"9000"则代表可能支付失败
                        // "8000"代表支付结果因为支付渠道原因或者系统原因还在等待支付结果确认，最终交易是否成功以服务端异步通知为准（小概率状态）
                        if (TextUtils.equals(resultStatus, "8000")) {
                            result = new PayResult(true,"","");
                        } else {
                            result = new PayResult(false,"pay.error","支付失败");
                        }
                    }
                    break;
                case SDK_CHECK_FLAG:
                    break;
                default:
                    break;
            }
            if(payHandler != null){
                payHandler.onResult(result);
            }
        }
    };
}
