package com.rnsocial.pay.channel;

import android.content.Context;

import com.rnsocial.pay.PayResultHandler;
import com.rnsocial.pay.PayService;
import com.rnsocial.pay.model.PayResult;
import com.tencent.mm.opensdk.constants.Build;
import com.tencent.mobileqq.openpay.api.IOpenApi;
import com.tencent.mobileqq.openpay.api.OpenApiFactory;
import com.tencent.mobileqq.openpay.constants.OpenConstants;
import com.tencent.mobileqq.openpay.data.pay.PayApi;

import java.util.Map;

/**
 * Created by ZYWu on 2017/7/20.
 */

public class QQWalletPay implements PayService {
    private IOpenApi openApi;
    private String QQAppID;
    private PayResultHandler payHandler;
    private String callbackScheme ;
    int paySerial = 1;

    public QQWalletPay(Context mContext, String appid,String scheme){
        init(mContext,appid,scheme);
    }

    @Override
    public void init(Context mContext, Object... args) {
        if(args.length < 1 || !(args[0] instanceof String || !(args[1] instanceof String))){
            return;
        }
        QQAppID = (String) args[0];
        openApi = OpenApiFactory.getInstance(mContext, QQAppID);
        callbackScheme = (String) args[1];

    }


    @Override
    public boolean checkSupport(Context mContext) {
        boolean isInstalled = openApi.isMobileQQInstalled();
        boolean isSupport = openApi.isMobileQQSupportApi(OpenConstants.API_NAME_PAY);
        return isInstalled && isSupport;
    }

    @Override
    public void pay(Context mContext, Map<String, Object> payArgs, PayResultHandler handler) {
        if(!checkSupport(mContext)){
            PayResult error = new PayResult(false,"qqwallet.not.install", "未安装QQ钱包客户端");
            handler.onResult(error);
            return;
        }
        if(openApi == null){
            PayResult error = new PayResult(false,"wallet.init.error", "QQ支付初始化失败");
            handler.onResult(error);
            return;
        }
        payHandler = handler;
        PayApi api = new PayApi();

        try {
            api.appId = QQAppID;
            api.serialNumber = payArgs.containsKey("serialNumber")?(String)payArgs.get("serialNumber"):"" + paySerial++;;
            api.callbackScheme = callbackScheme;
            api.sig =  (String)payArgs.get("sign");
            api.tokenId = (String)payArgs.get("tokenId");
            api.pubAcc = payArgs.containsKey("pubAcc")?(String)payArgs.get("pubAcc"):"";
            api.pubAccHint = payArgs.containsKey("pubAccHint")?(String)payArgs.get("pubAccHint"):"";
            api.nonce = (String)payArgs.get("nonce");
            api.timeStamp = System.currentTimeMillis() / 1000;
            api.bargainorId =(String)payArgs.get("bargainorId");
            api.sigType =payArgs.containsKey("signType")?(String)payArgs.get("signType"):"HMAC-SHA1" ;
        }catch (Exception e){
            PayResult error = new PayResult(false,"pay.error", "参数解析失败");
            handler.onResult(error);
            return;
        }
        if(api.checkParams()){
            openApi.execApi(api);
        }else{
            PayResult error = new PayResult(false,"pay.error", "参数解析失败");
            handler.onResult(error);
        }

    }

}
