package com.rnsocial.pay.channel;

import android.content.Context;

import com.rnsocial.pay.PayResultHandler;
import com.rnsocial.pay.PayService;
import com.rnsocial.pay.model.PayResult;
import com.tencent.mm.opensdk.constants.Build;
import com.tencent.mm.opensdk.modelpay.PayReq;
import com.tencent.mm.opensdk.openapi.IWXAPI;
import com.tencent.mm.opensdk.openapi.WXAPIFactory;

import java.util.Map;

/**
 * User : yh
 * Date : 17/5/4
 */

public class WechatPay implements PayService{
    private IWXAPI iwxapi;
    private String wechatAppId;
    private PayResultHandler payHandler;

    public WechatPay(){

    }

    public WechatPay(Context mContext,String appid){
        init(mContext,appid);
    }

    @Override
    public void init(Context mContext, Object... args) {
        if(args.length < 1 || !(args[0] instanceof String)){
            return;
        }
        wechatAppId = (String) args[0];
        iwxapi = WXAPIFactory.createWXAPI(mContext,wechatAppId,false);
        iwxapi.registerApp(wechatAppId);
    }


    @Override
    public boolean checkSupport(Context mContext) {
        return iwxapi.getWXAppSupportAPI() >= Build.PAY_SUPPORTED_SDK_INT;
    }

    @Override
    public void pay(Context mContext, Map<String, Object> payArgs, PayResultHandler handler) {
        if(!checkSupport(mContext)){
            PayResult error = new PayResult(false,"wechat.not.install", "未安装微信客户端");
            handler.onResult(error);
            return;
        }
        if(iwxapi == null){
            PayResult error = new PayResult(false,"wechat.init.error", "微信支付初始化失败");
            handler.onResult(error);
            return;
        }
        payHandler = handler;
        PayReq request = new PayReq();
        try {
            request.appId = (String)payArgs.get("appId");
            request.partnerId = (String)payArgs.get("partnerId");
            request.prepayId = (String)payArgs.get("prepayId");
            request.packageValue = (String)payArgs.get("package");
            request.nonceStr = (String)payArgs.get("nonceStr");
            request.timeStamp = (String)payArgs.get("timeStamp");
            request.sign = (String)payArgs.get("sign");
        }catch (Exception e){
            PayResult error = new PayResult(false,"pay.error", "参数解析失败");
            handler.onResult(error);
            return;
        }
        iwxapi.sendReq(request);
    }
}
